==> financial-settlement-client-0.0.170-sources.jar: com/xforceplus/financialsettlement/controller/ReconciliationDetailDataFeignApi.java <==
package com.xforceplus.financialsettlement.controller;


/**
 * ${table.comment}feign客户端
 *
 * @author ultraman
 * @date 2021-10-13
 */
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.GetMapping;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import org.springframework.web.bind.annotation.*;
import com.baomidou.mybatisplus.extension.api.R;
import com.baomidou.mybatisplus.core.toolkit.StringUtils;
import com.xforceplus.financialsettlement.entity.ReconciliationDetailData;
import lombok.AllArgsConstructor;
import org.springframework.stereotype.Controller;
import java.util.List;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;


@FeignClient(name = "financial-settlement")
public interface ReconciliationDetailDataFeignApi {

  /**
   * 通过id查询${table.comment}
   * @param  id
   * @return R
   */
  @GetMapping("/reconciliationDetailData/get/{id}" )
  public R getById(@PathVariable Long id);

  /**
   * 新增${table.comment}
   * @param reconciliationDetailData ${table.comment}
   * @return R
   */
  @PostMapping("/reconciliationDetailData/add")
  public R save(@RequestBody ReconciliationDetailData reconciliationDetailData);

  /**
   * 修改${table.comment}
   * @param reconciliationDetailData ${table.comment}
   * @return R
   */
  @PostMapping("/reconciliationDetailData/update")
  public R updateById(@RequestBody ReconciliationDetailData reconciliationDetailData);

  /**
   * 通过id删除${table.comment}
   * @param  id
   * @return R
   */
  @DeleteMapping("/reconciliationDetailData/del/{id}" )
  public R removeById(@PathVariable Long id);

}

==> financial-settlement-client-0.0.196-sources.jar: com/xforceplus/financialsettlement/controller/ReconciliationDetailDataFeignApi.java <==
package com.xforceplus.financialsettlement.controller;


/**
 * 对账单明细feign客户端
 *
 * @author ultraman
 * @date 2021-11-02
 */
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.GetMapping;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import org.springframework.web.bind.annotation.*;
import com.baomidou.mybatisplus.extension.api.R;
import com.baomidou.mybatisplus.core.toolkit.StringUtils;
import com.xforceplus.financialsettlement.entity.ReconciliationDetailData;
import lombok.AllArgsConstructor;
import org.springframework.stereotype.Controller;
import java.util.List;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;


@FeignClient(name = "financial-settlement")
public interface ReconciliationDetailDataFeignApi {

  /**
   * 通过id查询对账单明细
   * @param  id
   * @return R
   */
  @GetMapping("/reconciliationDetailData/get/{id}" )
  public R getById(@PathVariable Long id);

  /**
   * 新增对账单明细
   * @param reconciliationDetailData 对账单明细
   * @return R
   */
  @PostMapping("/reconciliationDetailData/add")
  public R save(@RequestBody ReconciliationDetailData reconciliationDetailData);

  /**
   * 修改对账单明细
   * @param reconciliationDetailData 对账单明细
   * @return R
   */
  @PostMapping("/reconciliationDetailData/update")
  public R updateById(@RequestBody ReconciliationDetailData reconciliationDetailData);

  /**
   * 通过id删除对账单明细
   * @param  id
   * @return R
   */
  @DeleteMapping("/reconciliationDetailData/del/{id}" )
  public R removeById(@PathVariable Long id);

}
